<a id="plugins.aea-ledger-fetchai.aea_ledger_fetchai.test_tools.constants"></a>

# plugins.aea-ledger-fetchai.aea`_`ledger`_`fetchai.test`_`tools.constants

Constants.

<a id="plugins.aea-ledger-fetchai.aea_ledger_fetchai.test_tools.constants.FETCHAI_P2P_ADDRESS"></a>

#### FETCHAI`_`P2P`_`ADDRESS

relates to NON_FUNDED_FETCHAI_PRIVATE_KEY_1

